
%-------------------------------------------------------------------------------
%   Create a 2-dimensional plot page. Any number of plots may be entered. 
%
%   If iY is not entered the number of y-axis labels will determine the number of
%   plots on the page. The number of rows of x must equal the number of x labels. 
%   If you enter only one row of x it will be used for all plots without the need 
%   to enter iX. Any of the inputs, except y, may be omitted or [].
%
%   For example, to plot a position in a (3,n) matrix:
%
%   Plot2D( t, r, 'Time', {'X','Y','Z'}, 'Position Vector' )
%
%   or even just
%
%   Plot2D( t, r )
%
%   To plot this position overlaid with a target, 
%   Plot2D(t,[r;rT],'Time',{'X','Y','Z'},'Position Vector',[],{[1 4],[2 5],[3 6]})
%
%-------------------------------------------------------------------------------
%   Form:
%   [h, hA] = Plot2D( x, y, xL, yL, figTitle, plotType, iY, iX, nCols, pThresh )
%-------------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   x          (m,:)      x values
%   y          (n,:)      y values
%   xL      (m,:) or {m}  x-axis label(s)
%   yL      (n,:) or {n}  y-axis label(s)
%   figTitle    (:)       Figure title
%   plotType   (n,4)      Type of axes 'xlog', 'ylog', 'log', 'lin'. 'lin' is the default.
%   iY      (n,:) or {n}  Index. Indexes Y data to plots. Each row or cell gives the indexes
%                         of the data that go on that plot. This is a string,
%                         either '[1 2 3 4]', '1:3', or an array.
%   iX         (n,1)      Index. Indexes X data to plots. Each row gives the indexes
%                         of the x data that goes with that plot
%   nCol       (1,1)      Number of columns.
%   pThresh    (1,1)      Minimum plot resolution. Set to 2.220446049250313e-10 for PowerPC
%                         Prevents a MATLAB warning that appears in V5.x.
%
%   -------
%   Outputs
%   -------
%   h          (1,1)    Figure handle
%   hA         (:)      Data structure of handles to line objects
%                       .h
%
%-------------------------------------------------------------------------------