
%-------------------------------------------------------------------------------
%   Computes the time derivative of a quaternion that transforms from
%   the inertial frame to the body frame given the angular velocity
%   measured in the body frame.
%-------------------------------------------------------------------------------
%   Form:
%   qD                 = QIToBDot( q, w )	
%   [a, b, c, d, dqdt] = QIToBDot( q, w )
%   [a, b, c, d, dqdt] = QIToBDot( q, w, dT )
%-------------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   q              (4,1)  Quaternion from a to b
%   w              (3,1)  Rate of b with respect to a measured in b
%   dT             (1,1)  Time step
%
%   -------
%   Outputs
%   -------
%   qD             (4,1)  Derivative of Q
%
%   or
%
%   a                     Plant matrix
%   b                     Input matrix
%   c                     Measurement matrix
%   d                     Feedthrough matrix
%   dqdt                  Constant quaternion derivative
%
%-------------------------------------------------------------------------------