
%-------------------------------------------------------------------------------
%   Computes the angular acceleration of a rigid body. 
%   invInr and t are not used when computing the state-space model. invInr is
%   optional when computing the right-hand-side but will speed up the routine.
%-------------------------------------------------------------------------------
%   Form:
%   wdot               = RBModel( inr, w, t, invInr )
%   [a, b, c, d, dwdt] = RBModel( inr, w, t, invInr, dT )
%-------------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   inr          (3,3)     Inertia matrix
%   w            (3,1)     Body rate in the body frame
%   t            (3,1)     External torque on the body
%   invInr       (3,3)     Inverse inertia matrix (Optional)
%   dT                     Time step
%
%   -------
%   Outputs
%   -------
%   wdot         (3,1)     Angular acceleration
%
%   or
%
%   a            (3,3)     State matrix
%   b            (3,3)     Input matrix
%   c            (3,3)     Output matrix
%   d            (3,3)     Feedthrough matrix
%   dwdt         (3)       State acceleration
%
%-------------------------------------------------------------------------------