
%-------------------------------------------------------------------------------
%   Computes the output of a rate integrating gyro package.
% 
%   dang/dt = w + b + nRW*randn 
%     db/dt =  -*b +  nb*randn
%
%   Includes a random walk and bias drift model.
%   The drift noise can be correlation
%
%   This routine does not check inputs.
%   The state vector is [angle; bias]
%-------------------------------------------------------------------------------
%   Form:
%   dxdt = RIGModel( u, w, b, nRW, nB, beta )
%-------------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   u            (3,n)     Unit vectors for the gyro axes in body axes
%   w            (3,1)     Body rates
%   b            (n)       Bias rate
%   nRW          (n)       Bias 1 sigma noise (random walk)
%   nB           (n)       Bias 1 sigma drift noise
%   beta         (n)       Bias correlation time constant
%
%   -------
%   Outputs
%   -------
%   dxdt         (2n)      [AngularRate dBias/dt]
%
%-------------------------------------------------------------------------------